Cython bindings for MurmurHash2
*******************************

.. image:: https://img.shields.io/travis/explosion/murmurhash/master.svg?style=flat-square
    :target: https://travis-ci.org/explosion/murmurhash
    :alt: Build Status
    
.. image:: https://img.shields.io/appveyor/ci/explosion/murmurhash/master.svg?style=flat-square
    :target: https://ci.appveyor.com/project/explosion/murmurhash
    :alt: Appveyor Build Status

.. image:: https://img.shields.io/pypi/v/murmurhash.svg?style=flat-square
    :target: https://pypi.python.org/pypi/murmurhash
    :alt: pypi Version
